@@ -1,14 +1,25 @@
 __author__ = 'Oleg Butovich'
-__copyright__ = '(c) Oleg Butovich 2013'
+__copyright__ = '(c) Oleg Butovich 2013-2017'
 __licence__ = 'MIT'
 
-import httplib
-import os
-import imp
-import urlparse
+import importlib
 import posixpath
 import logging
 
+# Python 3 compatibility:
+try:
+    import httplib
+except ImportError:  # py3
+    from http import client as httplib
+try:
+    import urlparse
+except ImportError:  # py3
+    from urllib import parse as urlparse
+try:
+    basestring
+except NameError:  # py3
+    basestring = (bytes, str)
+
 logger = logging.getLogger(__name__)
 
 
@@ -30,7 +41,7 @@ class ProxmoxResourceBase(object):
         return urlparse.urlunsplit([scheme, netloc, path, query, fragment])
 
 
-class ResourceException(StandardError):
+class ResourceException(Exception):
     pass
 
 
@@ -64,7 +75,8 @@ class ProxmoxResource(ProxmoxResourceBase):
         logger.debug('Status code: %s, output: %s', resp.status_code, resp.content)
 
         if resp.status_code >= 400:
-            raise ResourceException("{0} {1}".format(resp.status_code, httplib.responses[resp.status_code]))
+            raise ResourceException("{0} {1}: {2}".format(resp.status_code, httplib.responses[resp.status_code],
+                                                          resp.content))
         elif 200 <= resp.status_code <= 299:
             return self._store["serializer"].loads(resp)
 
@@ -91,11 +103,21 @@ class ProxmoxAPI(ProxmoxResourceBase):
     def __init__(self, host, backend='https', **kwargs):
 
         #load backend module
-        found_module = imp.find_module(backend, [os.path.join(os.path.dirname(__file__), 'backends')])
-        self._backend = imp.load_module(backend, *found_module).Backend(host, **kwargs)
+        self._backend = importlib.import_module('.backends.%s' % backend, 'proxmoxer').Backend(host, **kwargs)
+        self._backend_name = backend
 
         self._store = {
             "base_url": self._backend.get_base_url(),
             "session": self._backend.get_session(),
             "serializer": self._backend.get_serializer(),
-        }
\ No newline at end of file
+        }
+
+    def get_tokens(self):
+        """Return the auth and csrf tokens.
+
+        Returns (None, None) if the backend is not https.
+        """
+        if self._backend_name != 'https':
+            return None, None
+
+        return self._backend.get_tokens()
